qcacld-3.0: Rename osif_*_sync_create_with_trans()

Rename the osif_*_sync_create_with_trans() to a slightly more
appropriate osid_*_sync_create_and_trans(), to help convey the fact that
the transition does not end when the function returns.

Change-Id: I5606fb613d786d65de773dae49fe8ad431b5342f
CRs-Fixed: 2406713
diff --git a/core/hdd/src/wlan_hdd_driver_ops.c b/core/hdd/src/wlan_hdd_driver_ops.c
index 9738195..3378804 100644
--- a/core/hdd/src/wlan_hdd_driver_ops.c
+++ b/core/hdd/src/wlan_hdd_driver_ops.c
@@ -459,7 +459,7 @@
 
 	hdd_info("probing driver");
 
-	errno = osif_psoc_sync_create_with_trans(dsc_driver, &psoc_sync);
+	errno = osif_psoc_sync_create_and_trans(dsc_driver, &psoc_sync);
 	if (errno)
 		return errno;
 
diff --git a/core/hdd/src/wlan_hdd_p2p.c b/core/hdd/src/wlan_hdd_p2p.c
index 11b0adb..909593f 100644
--- a/core/hdd/src/wlan_hdd_p2p.c
+++ b/core/hdd/src/wlan_hdd_p2p.c
@@ -769,7 +769,7 @@
 	struct osif_vdev_sync *vdev_sync;
 	int errno;
 
-	errno = osif_vdev_sync_create_with_trans(wiphy_dev(wiphy), &vdev_sync);
+	errno = osif_vdev_sync_create_and_trans(wiphy_dev(wiphy), &vdev_sync);
 	if (errno)
 		return ERR_PTR(errno);
 
diff --git a/core/hdd/src/wlan_hdd_sap_cond_chan_switch.c b/core/hdd/src/wlan_hdd_sap_cond_chan_switch.c
index 4378627..ef71c8f 100644
--- a/core/hdd/src/wlan_hdd_sap_cond_chan_switch.c
+++ b/core/hdd/src/wlan_hdd_sap_cond_chan_switch.c
@@ -400,8 +400,8 @@
 	struct osif_vdev_sync *vdev_sync;
 	int errno;
 
-	errno = osif_vdev_sync_create_with_trans(hdd_ctx->parent_dev,
-						 &vdev_sync);
+	errno = osif_vdev_sync_create_and_trans(hdd_ctx->parent_dev,
+						&vdev_sync);
 	if (errno)
 		return errno;
 
diff --git a/os_if/nan/src/os_if_nan.c b/os_if/nan/src/os_if_nan.c
index 055248d..bd8a404 100644
--- a/os_if/nan/src/os_if_nan.c
+++ b/os_if/nan/src/os_if_nan.c
@@ -297,7 +297,7 @@
 	if (errno)
 		return errno;
 
-	errno = osif_vdev_sync_create_with_trans(dev, &vdev_sync);
+	errno = osif_vdev_sync_create_and_trans(dev, &vdev_sync);
 	if (errno)
 		return errno;
 
diff --git a/os_if/sync/src/osif_psoc_sync.c b/os_if/sync/src/osif_psoc_sync.c
index 0392b61..e889b91 100644
--- a/os_if/sync/src/osif_psoc_sync.c
+++ b/os_if/sync/src/osif_psoc_sync.c
@@ -126,9 +126,9 @@
 	return qdf_status_to_os_return(status);
 }
 
-int __osif_psoc_sync_create_with_trans(struct dsc_driver *dsc_driver,
-				       struct osif_psoc_sync **out_psoc_sync,
-				       const char *desc)
+int __osif_psoc_sync_create_and_trans(struct dsc_driver *dsc_driver,
+				      struct osif_psoc_sync **out_psoc_sync,
+				      const char *desc)
 {
 	struct osif_psoc_sync *psoc_sync;
 	QDF_STATUS status;
diff --git a/os_if/sync/src/osif_vdev_sync.c b/os_if/sync/src/osif_vdev_sync.c
index 163a03b..0b5416d 100644
--- a/os_if/sync/src/osif_vdev_sync.c
+++ b/os_if/sync/src/osif_vdev_sync.c
@@ -125,9 +125,9 @@
 	return qdf_status_to_os_return(status);
 }
 
-int __osif_vdev_sync_create_with_trans(struct device *dev,
-				       struct osif_vdev_sync **out_vdev_sync,
-				       const char *desc)
+int __osif_vdev_sync_create_and_trans(struct device *dev,
+				      struct osif_vdev_sync **out_vdev_sync,
+				      const char *desc)
 {
 	struct osif_vdev_sync *vdev_sync;
 	QDF_STATUS status;
diff --git a/os_if/sync/inc/osif_psoc_sync.h b/os_if/sync/inc/osif_psoc_sync.h
index f7ec756..38969f9 100644
--- a/os_if/sync/inc/osif_psoc_sync.h
+++ b/os_if/sync/inc/osif_psoc_sync.h
@@ -40,7 +40,7 @@
 		      struct osif_psoc_sync **out_psoc_sync);
 
 /**
  * osif_psoc_sync_create_with_trans() - create a psoc synchronization context
  * @dsc_driver: parent dsc_driver to the psoc
  * @out_psoc_sync: out parameter for the new synchronization context
  *
@@ -48,13 +48,13 @@
  *
  * Return: Errno
  */
-#define osif_psoc_sync_create_with_trans(dsc_driver, out_psoc_sync) \
-	__osif_psoc_sync_create_with_trans(dsc_driver, out_psoc_sync, __func__)
+#define osif_psoc_sync_create_and_trans(dsc_driver, out_psoc_sync) \
+	__osif_psoc_sync_create_and_trans(dsc_driver, out_psoc_sync, __func__)
 
 qdf_must_check int
-__osif_psoc_sync_create_with_trans(struct dsc_driver *dsc_driver,
-				   struct osif_psoc_sync **out_psoc_sync,
-				   const char *desc);
+__osif_psoc_sync_create_and_trans(struct dsc_driver *dsc_driver,
+				  struct osif_psoc_sync **out_psoc_sync,
+				  const char *desc);
 
 /**
  * osif_psoc_sync_destroy() - destroy a psoc synchronization context
@@ -40,7 +40,7 @@
 
 /**
- * osif_psoc_sync_create_with_trans() - create a psoc synchronization context
+ * osif_psoc_sync_create_and_trans() - create a psoc synchronization context
  * @dsc_driver: parent dsc_driver to the psoc
  * @out_psoc_sync: out parameter for the new synchronization context
diff --git a/os_if/sync/inc/osif_vdev_sync.h b/os_if/sync/inc/osif_vdev_sync.h
index fef5514..0993cb0 100644
--- a/os_if/sync/inc/osif_vdev_sync.h
+++ b/os_if/sync/inc/osif_vdev_sync.h
@@ -40,7 +40,7 @@
 		      struct osif_vdev_sync **out_vdev_sync);
 
 /**
  * osif_vdev_sync_create_with_trans() - create a vdev synchronization context
  * @dev: parent device to the vdev
  * @out_vdev_sync: out parameter for the new synchronization context
  *
@@ -48,13 +48,13 @@
  *
  * Return: Errno
  */
-#define osif_vdev_sync_create_with_trans(dev, out_vdev_sync) \
-	__osif_vdev_sync_create_with_trans(dev, out_vdev_sync, __func__)
+#define osif_vdev_sync_create_and_trans(dev, out_vdev_sync) \
+	__osif_vdev_sync_create_and_trans(dev, out_vdev_sync, __func__)
 
 qdf_must_check int
-__osif_vdev_sync_create_with_trans(struct device *dev,
-				   struct osif_vdev_sync **out_vdev_sync,
-				   const char *desc);
+__osif_vdev_sync_create_and_trans(struct device *dev,
+				  struct osif_vdev_sync **out_vdev_sync,
+				  const char *desc);
 
 /**
  * osif_vdev_sync_destroy() - destroy a vdev synchronization context
@@ -40,7 +40,7 @@
 
 /**
- * osif_vdev_sync_create_with_trans() - create a vdev synchronization context
+ * osif_vdev_sync_create_and_trans() - create a vdev synchronization context
  * @dev: parent device to the vdev
  * @out_vdev_sync: out parameter for the new synchronization context